Afrikaans
Akan
Albanian
Amharic
Arabic
Armenian
Azerbaijani
Basque
Belarusian
Bemba
Bengali
Bihari
Bosnian
Breton
Bulgarian
Cambodian
Catalan
Cebuano
Cherokee
Chichewa
Chinese (Simplified)
Chinese (Traditional)
Corsican
Croatian
Czech
Danish
Dutch
Esperanto
Estonian
Ewe
Faroese
Filipino
Finnish
Frisian
Ga
Galician
Georgian
German
Greek
Guarani
Gujarati
Haitian Creole
Hausa
Hawaiian
Hebrew
Hindi
Hmong
Hungarian
Icelandic
Igbo
Indonesian
Interlingua
Irish
Italian
Japanese
Javanese
Kannada
Kazakh
Kinyarwanda
Kirundi
Kongo
Korean
Krio (Sierra Leone)
Kurdish
Kurdish (Soranî)
Kyrgyz
Laothian
Latin
Latvian
Lingala
Lithuanian
Lozi
Luganda
Luo
Luxembourgish
Macedonian
Malagasy
Malay
Malayalam
Maltese
Maori
Marathi
Mauritian Creole
Moldavian
Mongolian
Myanmar (Burmese)
Montenegrin
Nepali
Nigerian Pidgin
Northern Sotho
Norwegian
Norwegian (Nynorsk)
Occitan
Oriya
Oromo
Pashto
Persian
Polish
Portuguese (Brazil)
Portuguese (Portugal)
Punjabi
Quechua
Romanian
Romansh
Runyakitara
Russian
Samoan
Scots Gaelic
Serbian
Serbo-Croatian
Sesotho
Setswana
Seychellois Creole
Shona
Sindhi
Sinhalese
Slovak
Slovenian
Somali
Spanish
Sundanese
Swahili
Swedish
Tajik
Tamil
Tatar
Telugu
Thai
Tigrinya
Tonga
Tshiluba
Tumbuka
Turkish
Turkmen
Twi
Uighur
Ukrainian
Urdu
Uzbek
Vietnamese
Welsh
Wolof
Xhosa
Yiddish
Yoruba
Zulu
ROBOCALLER 1: I'm so glad I reached you.
That last person I talked to liked me about as much
as my mother-in-law. (CHUCKLING)
hi there. You know, getting a hold of you
is tougher than getting through boot camp. (CHUCKLING)
ROBOCALLER 3: You're the first person
I reached in 15 minutes and I'm pretty tall.
-(ROBOCALLERS CHUCKLING) -♪ (TENSE MUSIC PLAYING) ♪
ROBOCALLER 4:
the reason for my call is...
ROBOCALLER 5:
ROBOCALLER 6:
ROBOCALLER 7:
ROBOCALLER 8:
-(OVERLAPPING CHATTER) -(MESSAGES PINGING)
-♪ (TENSE MUSIC CONCLUDES) ♪ -(BIRDS CHIRPING)
are you there?
are you there?
are you there?
♪ (SUSPENSEFUL MUSIC PLAYING) ♪
there was a solid year where I was pretty sure
he was either dead or in jail.
I heard he got his shit together
and was working at a gas station.
guys. Uh, Patrick J. Pespas.
SAM: There were times
but then years would go by when we didn't talk at all.
sort of, assumed the worst.
one day, I got a call from him
and he sounded totally different.
PATRICK J. PESPAS: (OVER PHONE)
SAM: I'd already given up on the CDG story by that point.
shot a few weddings,
some foot stuff. -ACTRESS: (OVER SPEAKER) Mm.
SAM: I didn't even know I had a Cousin Adam.
and the scam that was still going on
and he was down to come with me to Jersey.
bro.
(LAUGHS)
SAM: I had no idea
how much more insane telemarketing had gotten.
I was just happy that I was gonna see Pat.
(ENGINE ROARING)
♪ (SUSPENSEFUL MUSIC CONCLUDES) ♪
it's gotta be, like, eight years now.
(LINE RINGING)
PATRICK:
what's up man? -PATRICK:
dude.
lemme just...
PATRICK:
-SAM: You look good man. -PATRICK:
you look real good.
-(CHUCKLES) -PATRICK:
you fat bastard.
-(GROANS) -♪ (SOFT MUSIC PLAYING) ♪
my God. What a cute-- -Yeah. He's a fat, striped bastard
-is what he is. -(SAM CHUCKLES)
man. Gimme a hug, bro. Can we-- can we do a hug?
man.
I fucking respect you.
Pat seemed like he was in a really good place.
I'd actually never seen him look that healthy.
But Sue was a different story.
me and Sue, um,
we dated years and years ago.
you know,
I was a fuckup. And then she got cancer.
And I did my best to take care of her.
the radiation
but it was worth it
because now her cancer is in remission.
SUE: Twenty-seven years we've been together now.
SAM: You guys have been 27 years. Wow!
from the moment I wake up
my world revolves
around him and vice versa.
that's...
I don't know what I'd do if I lost Pat.
I don't know what I'd do. And he feels the same way.
thank you for letting us film.
Really appreciate it.
♪ (SOFT MUSIC CONCLUDES) ♪
You think?
It is. A little bit.
Are you?
I am.
I am.
♪ (TENSE MUSIC PLAYING) ♪
when we began getting bombarded with pre-recorded robocalls.
-(CELL PHONE RINGING) -PATRICK: Massachusetts.
Okay. Hello.
I'm glad you picked up.
I was getting my answering machine voice ready. (LAUGHS)
ROBOCALLER 2:
SAM: And they were just as deceptive
as anything we had done at CDG.
-SAM: Try it one more time. -ROBOCALLER 3:
you're an officer, yes?
ROBOCALLER 3:
I was just asking, you're an officer, yes?
ROBOCALLER 3:
listen, I can do the gold then.
this is gonna help out locally, right?
uh, my hometown.
ROBOCALLER 3:
great, great.
Are you at the police department right next door?
ROBOCALLER 3:
(SAM AND PATRICK CHUCKLE)
SAM: There were always calls for Political Action Committees
and half the robots would say they were cops.
But then we started getting robocallers we actually knew.
ROBOCALLER 4:
SAM: Joe-- Joe Makko!
(CHUCKLES)
guys. Uh, Patrick J. Pespas.
uh, Joe Makko.
ROBOCALLER 4:
Officer Makko. -(CHUCKLES)
right?
ROBOCALLER 4:
that dude's been dead for a year.
that's... That's wild. That's some wild shit.
SAM: None of our old CDG friends knew very much about robocalls
except for Billy Fedor.
Who the fuck's making these robocalls?
But where-- But from where?
-Like-- -BILLY FEDOR:
SAM: I knew he had worked for a big-time telemarketer
but I also knew he fucking hated it.
Billy worked there for years and he fucking knows everything.
Billy has a big mouth and we want any dirt he's got.
-Fucking Pat Pespas? -PATRICK: Yeah!
it's me, man.
BILLY: Wow!
Holy shit.
um,
I guess that... (REDACTED)
huh? -Yeah.
PATRICK: What did you think of that place?
yeah.
scam, right?
even worse. But, yeah.
even worse.
PATRICK: I'm-- I'm running an investigation into the scams.
yeah? -PATRICK: Yes, I am.
I mean... (REDACTED)
...are huge right now. They have people
in Nevada, California.
PATRICK: And you were calling for what?
non-profits or... -Oh, yeah. We were doing
non-- supposed "nonprofits."
-"501-c-3s." -PATRICK: Okay.
uh, we were doing the PACs, the Political Action Campaigns.
you know, in this day and age
they use it to their advantage.
killing it.
-Just killing it. Killing it. -PATRICK: Collecting money.
um, robocalls now, uh,
this artificial intelligence?
but I also knew that everyone's jobs there
are gonna be eventually in danger
like,
I haven't worked there in two-- over two years.
next month. -PATRICK: Okay.
And they still have me calling for them.
now it's a bot.
BILLY: You could have a real-life person
closing sales for you without having to even pay them.
-♪ (SUSPENSEFUL MUSIC PLAYING) ♪ -SAM: It had been nine years
since I contacted the Federal Trade Commission
to find out how these kinds of places could still exist.
And why the police involvement is always swept under the rug.
Pat?
But that's when Pat disappeared
and the investigation fell apart.
PATRICK: (OVER PHONE) I...
SAM: I got back in touch with the actual guy
and he was still willing to meet with us
after all these years.
what's up, man?
I almost forgot.
my travel papers.
This is the crazy part. The program I'm on is so strict.
from the pro--
giving me permission to take it with me.
wow. Okay. -And to clue everybody in that,
this kid's legit."
dude.
-Travel papers. It's like... -SAM: Shit.
yeah, yeah, yeah.
♪ (TENSE MUSIC PLAYING) ♪
-(CAR DOOR CLOSES) -(CAR ALARM BEEPS)
SAM: Thank you for taking the time to do this.
yeah. Well, this is the case
-that really stood out... -SAM: Yeah.
...'cause I really wanted these guys to go to jail.
are Keezer
do you know?
-One of them-- -I think they're both alive.
I probably paid his mortgage a few times.
I was one of their better callers.
you did?
yeah. -DAVID: Now,
I'm having regrets 'cause we didn't go
-after you guys as well. -SAM: True.
-(CHUCKLES) -PATRICK: There you go.
obviously, there's a police union involvement.
Fraternal Order of Police lodges partnered
with Civic Development Group.
"Well, what if we change
the office and we call it
the Fraternal Order of Police Fundraising Center?"
yeah, that's what-- that's what--
that's what the Civic Development Group did.
it was--
the same CDG office.
right?
it was...
-So... -(OVERLAPPING CHATTER)
right? -Pat, let me just... (CHUCKLES)
Why wasn't the Fraternal Order of Police
held accountable? 'Cause it seemed like
they were like this with Civic Development Group
for...
for them, it's free money.
Right? They didn't pay a penny.
Ten percent of something
is better than 100 percent of nothing.
I mean it's just simple math.
But aren't they-- they culpable in that crime?
in my mind... -There are complications
about going after police departments
and Fraternal Orders of Police. Um...
for example, like... -I...
these are police officers, you know?
What do they know about telemarketing?
reading the--
-like some of the evidence... -Right.
communicating with presidents of the FOP.
they were creating the scripts with them.
yeah, we knew that.
But-- but the dominant fundraising was done
by CDG people just masquerading as members
of the Fraternal Order of Police...
And the police knew they were masquerading.
-DAVID: Right... -I mean...
no. I know! -Like you said, it was such bullshit,
they knew.
you can't say they didn't.
I understand that. -PATRICK: Okay.
you know, look.
there really is that kind of
-symbiotic connection. -SAM: It seems like it.
DAVID: We did a lot of investigations.
fundraising effort. -Yeah.
But you saw it in that particular one
that you went after CDG for.
and that-- -But you didn't go after
the Fraternal Order of Police at all.
lost their jobs.
-That's great. -I felt no sympathy at all
I'm sure you don't.
-It's just to me as a... -'Cause... yeah--
'Cause the business of-- of the boiler room
so I did not care one whit
that all of you guys were unemployed.
totally. Fair enough. -No, I hear you,
-but you know-- -Did not shed--
-shed a tear. -SAM: Yeah.
legitimizes it.
Right. Yeah.
you know? -DAVID: I get that.
they moved to these PACs and it's like the Wild West now.
Congress is gonna have to do something about that
'cause the FTC cannot.
PATRICK: Why can't the government just stop this?
Because police unions are incredibly powerful.
♪ (PENSIVE MUSIC PLAYING) ♪
DAVID: That's the argument.
who wants to be on the other side
of the Fraternal Order of Police?
that's crazy. (CHUCKLES)
it makes sense.
Yeah.
I mean...
SAM: Yeah. (CHUCKLES)
this is like a tsunami
ready to drop.
like, nobody.
15-dollars-an-hour,
welcome to McDonald's," type of guy.
I don't have a college degree.
I don't got 100 initials after my name.
It doesn't say "Esquire" on my wall.
Who knows what we're dealing with?
And they'll-- they'll squash you like a bug.
let's call ourselves fucking journalists.
-Fuck it. -We are journalists.
SAM: We have to be in fear because of the truth.
yeah, I am fucking scared.
when you put it like that. Because if he's scared...
Whoo!
SAM: We were totally in over our heads
and started looking to see if any real journalists
were taking this thing on.
So Pat and I reached out to Sarah Kleiner.
She'd been writing about fundraising scams
for years
and was the only reporter I'd seen
who knew the police unions weren't the victims.
But the charities are well aware of what's going on.
they're well aware that this money is being raised
and that they are giving up most of it.
I didn't really think
she'd take us seriously.
But when I sent her our CDG footage
she freaked the fuck out.
SARAH KLEINER: I was giddy
I mean, I had documents,
but you guys had all the stories.
we came at it from the other end.
Yeah. What you're investigating has been going on
very long time.
it just keeps popping back up.
just to give you an example,
IUPA,
another group where we're seeing this huge amount of money
is going into telemarketing
and a teeny tiny amount is going into charity.
17,000 dollars.
000 dollars.
(EXHALES)
SARAH: I tried to get IUPA to comment
on the fundraising practices.
would not return emails. They wouldn't respond.
my grandma.
they think they're doing good,
but really they're enriching businessmen who have figured out
in many cases,
it's a civil penalty.
-It's a slap on the wrist. -PATRICK: Yeah.
SARAH: I actually tracked down one of the guys
who owns different telemarketing companies.
I went into his office and he chased me
into the parking lot.
-Did he really? -SARAH: He did. He--
what do you mean he chased you? -That's great. That's great.
SARAH: (ON RECORDING) I have questions for you
about your businesses and how much--
RICHARD ZEITLIN: Call the police because she's not getting out of here.
You understand I want you outta here?
I don't come to your house and block the front
of your door. Don't come to mine.
SARAH: You've raised 126 million dollars
bye-bye.
SARAH: And most of that has stayed with you
and has not gone to charity. How do you justify that?
I'm gonna come at you.
Here's your license plate number. You know what I'm gonna do?
I'm gonna track you down. See where you come from.
it was a little nerve-racking.
SAM: Can we go on adventures with you?
so...
We're picking up the gauntlet from you.
♪ (TENSE MUSIC PLAYING) ♪
SARAH: It's really cool that you have these stories
but I think that what you're really gonna need to do
is find out more about the modern day CDG.
Who is still doing this?
'Cause we know it's still happening.
(LINE RINGING)
-Yo! -MATT DEANE: (OVER PHONE) Aha!
Pespas.
Matt? -MATT: What's up, buddy?
-ED HILGER: Speaking of dope... -Pat fucking Pespas.
Matt. I'm calling...
um,
I'm kind of looking for a job.
um, companies
that are hiring? I know some of the guys
uh, that one place.
dude.
well, um, what do they call for? The FOP?
MATT:
no-- -MATT:
really? They bought CDG's old list.
MATT:
um, you know, get going on this.
you know, I can call.
if you hire me,
I'm gonna hit the list.
MATT:
Matt.
MATT:
-That's perfect. I will get that job. -There you go.
uh...
so be quiet. -SAM: Might as well answer...
Hello?
this is, uh, Patrick. What's up?
TELEMARKETER: This is... (REDACTED) ...from... (REDACTED)
beautiful. Hey, you know, I'm looking for a job.
they know me.
bro.
TELEMARKETER:
I got a laptop.
TELEMARKETER:
um,
-is that gonna matter? -TELEMARKETER:
perfect.
great, great. Thank you... (REDACTED)
TELEMARKETER:
excellent. Thank you. Bye-bye.
we hit the homerun... -SAM: Damn! You're a fucking legend, bro.
huh? -SAM: Fucking legend.
he called back quick.
♪ (TENSE MUSIC CONCLUDES) ♪
how do I look in the wardrobe, like,
with-- with the glasses and everything?
-SAM: Yeah. Yeah. -Yeah? It's good?
they're gonna see me, so...
but I think you look good.
you know.
First day on the job you know. Come on.
-(LINE RINGING) -(LAPTOP CHIMES)
PATRICK: Hello? Hello?
(OVER HEADSET)
-(CHUCKLES) -MANAGER:
Mr. Galvus.
GALVUS:
RECEIVER 1:
-How you doing? -RECEIVER 1:
calling for the Police Association of Virginia.
-How are ya? -RECEIVER 2:
You sound very young though.
uh, gold level at 45,
which is best for you?
RECEIVER 4:
RECEIVER 5:
you want to do 55?
They have the big booster at 35...
I feel bad closing these people.
dude.
You're undercover. That's how it goes.
PATRICK: My internet went down.
So I just ran down the street to a McDonald's.
Mr. Pearson. -PEARSON: Yeah.
-Mr. Gomez. -GOMEZ: What's up?
-Eddie... Betty... Kevin. -KEVIN: This is him.
(LAUGHS)
who's the best caller? Who's my competition?
♪ (TENSE MUSIC PLAYING) ♪
this is Thomas Bailiff, Paul.
I was calling with a thank you call
on behalf of the Volunteer Firefighters Alliance.
How are you--
TRAINER:
I dug for dirt on the shady-sounding nonprofits
that he was calling for.
Patrick J. Pespas
...the Texas Coalition of Police and Sheriffs.
...calling for the National Emergency Responders Coalition.
SAM: And a bunch of them were affiliated with IUPA.
The police union
that Sarah Kleiner had told us about.
right? -TRAINER:
and they know what the scripts are
right?
TRAINER:
cool.
SAM: Pat was killing it.
So... (REDACTED) ...took him off cold calls
and put him on the big money campaigns.
TRAINER: (OVER HEADSET)
thank you for that. I really had to go, man.
The doctor put me on some new medication
and it seems to make me go whizz a lot.
TRAINER:
my day, we didn't have PACs.
Is that a new thing?
TRAINER:
Why the switch? What is the difference like...
TRAINER:
Did they really?
it's easier to get a sale.
TRAINER:
that's cool.
so maybe we can make more sales.
TRAINER:
♪ (SUSPENSEFUL MUSIC PLAYING) ♪
(OVER PHONE)
(SPEAKS INDISTINCTLY)
SARAH:
♪ (SUSPENSEFUL MUSIC CONCLUDES) ♪
I'm doing a little...
you know. -CREW MEMBER 2: Yeah, yeah, yeah.
-PATRICK: Ann Ravel! -ANN RAVEL: How are you?
too.
PATRICK: Thank you for your time.
no problem. -Yes. May I call you Ann?
of course you may. (CHUCKLES) -Okay. Oh, fantastic.
you know, here, uh,
-we're gonna play for you. -Okay.
maybe, see what you think of this.
I'm very bad with technology, so...
BEEPS)
PAC campaigns are completely different?
That's me.
The other guy is the guy who runs the office.
but you just don't have to disclose
that you're a paid caller for... (REDACTED)
it's an easier call?
-TRAINER: Yeah. -PATRICK: Beautiful.
-do you have to tell them? -TRAINER: If you're calling
-you do not have to tell them... -That's right.
cool. Fantastic.
-That gives me-- -(PHONE RINGING)
Whoa. Oh!
-(RINGING STOPS) -PATRICK: I am so sorry about that.
-But you get the idea. -I-- I do get the idea.
-You get the idea. -They know it's so much easier
uh, when you're a PAC
than when you are a legitimate charity.
PACs are political
they have First Amendment protections.
people who were having to follow the rules
uh, laws,
"We're gonna go become a political PAC."
which is people are defrauding people.
you know,
really.
I'm a little new to the PAC game.
-ANN: Mm-hmm. -Um...
one of these ladies asked me
what the PAC is really receiving.
And he said they don't have to tell.
They could be keeping 100 percent of that money.
-We'll never know. -That's insane.
crazy. It's crazy. -ANN: Crazy.
we actually wrote to Congress
"You know, you need to deal
with the scam PAC problem."
It went nowhere.
basically, the laws haven't caught up with the industry.
ANN: That's correct.
of course.
Because I think it's straightforward fraud.
It's bank robbery.
-Legal bank robbery. -It is. It is.
-I seem to agree... -ANN: Mm-hmm.
-...with everything you say. -ANN: That's...
You're very knowledgeable on the subject
too.
One of my aspirations is to testify
you know?
I... In a sense, you're being
which is a good thing.
-Yes. Yes. -ANN: That is a good thing.
-Absolutely. -ANN: Because you have
"I saw this.
I know this is what was being done
I give you a lot of credit.
-I really admire you doing that. -♪ (SUSPENSEFUL MUSIC PLAYING) ♪
ANN: I could talk to some of my friends on the Hill.
I'll do what I can to help you.
I appreciate that. -I really will. You know that.
Thank you. It was so good to meet you.
-Really. Seriously. -(SPEAKS INDISTINCTLY)
♪ (SUSPENSEFUL MUSIC CONTINUES) ♪
dude. Ann called me a whistleblower.
I guess you could say I am a whistleblower.
I never did.
I always thought
I guess you could say I'm a fucking whistleblower.
SAM: We still wanted to get a police union
to talk about this shit on the record.
So we cold-called state FOPs from all across the country
and asked them if they'd talk
-about their fundraising. -(INDISTINCT CHATTER)
SAM: We even tried emailing the new president
of the national FOP.
except for the Florida State FOP.
They even sounded eager for the opportunity.
(SARAH CHUCKLES OVER PHONE)
♪ (SUSPENSEFUL MUSIC CONTINUES) ♪
Pat.
Pat.
Pat!
ADAM BHALA LOUGH: Pat's having a massive panic attack right now.
It's his first time on a plane. He's freaking the fuck out.
Pat!
-ADAM: You're gonna be good. -SAM: You're gonna be fine.
The first step is just getting inside.
-ADAM: Yeah. -Just don't even think past that.
-All right? -PATRICK: Okay.
-SAM: Let's just get you inside. -PATRICK: It's not like going
is it? -ADAM: Nah.
ANNOUNCER: (OVER PA) Regular boarding will begin
in approximately ten minutes' time. Thank you.
PATRICK:
but, dude,
it's not-- it's not possible.
PATRICK:
And I'm driving--
bro. -PATRICK:
ADAM: No. I need you at this shoot.
PATRICK: I can't bring myself to do it.
ladies and gentlemen,
United flight 217 is closing doors in...
please.
I apologize. And I'm done. I'm out of here.
-ADAM: All right. -PATRICK:
SAM: All you have to do is get on the seat.
(ADAM EXHALES)
♪ (HEAVY METAL MUSIC PLAYING OVER SPEAKER) ♪
SAM: I think it's gonna be like a three-day trip.
but I'd say it's gonna be three days.
-SAM: Three-day trip. -PATRICK: We'll get there.
yeah, yeah. -PATRICK: We'll get there in time.
SAM: Did she say anything about this trip?
Did you tell her?
-PATRICK: Of course. -SAM: What did she say?
"Look, Sam's your best friend.
You started the project with him. See it through."
man.
you know, she thinks I'm a complete idiot
for not getting on a plane.
♪ (PENSIVE MUSIC PLAYING) ♪
SAM: Oh shit! Supporter decal.
PATRICK: There-- There we go.
too. The red one's FOP.
SAM: We're seeing these stickers everywhere.
PATRICK: Everywhere. My guess this is FOP country out here.
dude. This looks like great shit.
bud.
Look at that fucking thing. (CHUCKLES)
PATRICK: Oh! Right in his head.
ADAM:
♪ (TENSE MUSIC PLAYING) ♪
VOICEMAIL: You have one new voice message.
First unheard message.
NOEL:
we get down here
and the fact that these guys canceled
is really burning my fucking ass.
you know, we gave these people an opportunity.
we were nice about it,
and they all don't want to talk about it.
now, we're gonna get a little pushy about it.
"We're getting this interview.
Michael Moore style."
what's up? -SAM: Hey, how's it going?
um, I'm here to see Noel.
-She said we're interviewing with her today. -OFFICER:
PATRICK: What?
SAM: Do you-- Can we just do
-something with you guys? -OFFICER:
-I'm the president of this organization. -PATRICK: No problem.
I run this building. Step outside.
gentlemen, have a nice day. -PATRICK: Thank you.
-Damn. -OFFICER: Take care.
-Have a nice day. -(ADAM CHUCKLES)
SAM: Let's get the fuck out of here.
He was hot. I thought
they were gonna physically attack us.
but we realized
IUPA.
The one that Sarah had told us about
and the one that Pat fundraised for undercover.
...throughout the state.
SAM: Their national headquarters were three hours away.
"Fuck it.
Let's see what they've got to say."
SAM:
IUPA REPRESENTATIVE 1: May I help you?
yeah. Um, my name is Patrick Pespas.
I'm a freelance journalist
and I am doing a documentary on fundraising
uh, nonprofits and PACs,
and your name has come up a lot.
Do you think there's anybody I could talk to?
IUPA REPRESENTATIVE 1:
I traveled a long way.
IUPA REPRESENTATIVE 1:
man.
Just tell her...
IUPA REPRESENTATIVE 2:
my name is Patrick J. Pespas.
I'm a freelance journalist.
IUPA REPRESENTATIVE 2:
No problem. Thank you for your time.
SAM: No comment.
let's just go, Sam. Get out of here.
SAM: Neither of us wanted to accept
that this trip would be a wash.
I tried thinking of ways to save it.
♪ (TENSE MUSIC CONCLUDES) ♪
I'm pretty sure... (REDACTED)
...lives out here.
JEFF: (IN DISTORTED VOICE)
yeah, yeah.
he says that I should come see him.
-♪ (TENSE MUSIC PLAYING) ♪ -(DOG BARKING)
-SAM: How you been man? -JEFF:
-SAM: Yeah? -JEFF:
-So are you out of the industry? -JEFF:
-You're done. -JEFF:
man. Um... Yeah. -JEFF:
-What did you say? Sorry. -JEFF:
-SAM: You wanna get some food? -JEFF:
SAM:
JEFF:
(RAIN PATTERING)
PATRICK: The bribes. The bribes.
I'm coming.
we found a story breaking in Texas
that changed everything for us.
REPORTER 1: ...investigates a former police union president
and tens of thousands of dollars in unexplained expenses.
000 on a Caribbean cruise.
Hundreds more at beach bars in Cozumel and Belize.
600 dollars spent
-on Houston Rockets tickets... -PATRICK: What...
bank records show,
to the Houston Metro Fraternal Order of Police.
Robert Lozano.
Whoo!
SAM: But this dude wasn't just stealing money
from his union.
too.
that raised money for FOP programs
to help needy kids.
His company kept a large chunk of those donations
and the rest went to the general FOP account
that was bled dry.
"Yeah, fine.
He got kicked out of FOP Lodge 98 or whatever."
But he denied any wrongdoing
and was never charged with a crime.
He kept his job as a cop.
still raising money in the name of the police.
♪ (TENSE MUSIC FADES) ♪
we gotta talk to this guy.
we just drove to Florida
and they all backed out.
You really think this guy is gonna talk?
"The blue wall of silence."
you know? -SAM: Yeah...
-That's just what I've heard. -...that's what they call it. You're right.
to land it,
man. I gotta talk to this guy.
dude.
This is gonna make or break this whole fucking thing.
SAM: I guess we're driving to Texas.
♪ ("DADDY JUST CALLED IT THE BLUES" BY JAMES TALLEY PLAYING) ♪
Lord And John the Conqueroo ♪
♪ Shotgun shacks And railroads tracks... ♪
hats are big here in Texas.
I'd like the color, but it needs to be bigger.
-I think this is it. -SAM: Four hundred dollars?
I have good cheeks. (CHUCKLES)
SAM: What's the cheapest hat you have?
let's-- let's try the Cody James.
-♪ (SONG FADES) ♪ -♪ (OMINOUS MUSIC PLAYS) ♪
♪ (OMINOUS MUSIC FADES) ♪
check it out, we're right across the street
from where Lozano works
and we saw a little barbecue pit.
hang out.
this is gonna be messy.
but it's good. Oh! That's some good stuff, man.
SAM: I love investigative journalism.
-People say it's a dying field. But it's-- -PATRICK:
-SAM: Yeah. A lot of journalists-- -PATRICK:
-♪ (TENSE MUSIC PLAYING) ♪ -SAM AND PATRICK: Oh!
there he is. Oh, shit. Yeah.
quick, quick. Let's leave the food.
It's right across the street. (CHUCKLES)
go, go, go, go! (LAUGHS)
-(INDISTINCT CHATTER) -PATRICK: Mr. Lozano!
excuse me, Mr. Lozano.
Mr. Lozano.
-I'm a freelance journalist. -SAM: Hey.
shit.
bro. Whoa! -(ENGINE REVS)
SAM: Yo! (LAUGHS)
PATRICK: Can you believe that?
I didn't know what to do. I had like barbecue on my hands.
I couldn't talk 'cause of food in my mouth.
SAM: Dude these people can only ignore us for so long.
We were in the middle of chasing Lozano
when we finally got a breakthrough.
His scandal had gone national.
we're gonna get somewhere now.
so they'd better listen
because now they have a chance
to get on the right side of this issue.
SAM: We suddenly started getting calls back
from lodges who'd been ignoring us.
it was the head of the Texas State FOP.
He had decided to stop using third-party telemarketers
and was ready to talk.
Connecticut and South Carolina State Lodges.
They all told us we could interview them
at the upcoming National FOP convention in Philly.
-PATRICK: Yeah! -SAM: Whoo! We feel good?
-♪ (SOFT MUSIC PLAYING) ♪ -PATRICK: Hallelujah!
God is smiling on us, bro.
God has been smiling on this trip
since I walked away from the plane.
That's awesome!
♪ (SOFT MUSIC FADES) ♪
-PATRICK: There's my upstairs neighbor. -SAM: Oh cool.
Anita?
how you doing, Pat? You started your YouTube?
yeah, you know. Travel America, baby.
Pat is a good person. Pat is a-- Pat is a good guy.
eh? -He did very well with his wife
he did a damn good job.
'Cause she ain't in there no more.
-So he did a damn good job. -NEIGHBOR 1: That's good.
-SAM: God bless you. -It gets no better than that.
you're a good motherfucker.
it is.
SAM: Do you know everyone?
Patrick. What's up?
-PATRICK: I'm going to Philly. -NEIGHBOR 2: Okay.
PATRICK: I'll be gone four days.
NEIGHBOR 2: Good.
let me get my shoes on.
SUE: I'm trying to get you guys out of here.
PATRICK: I know. I'm trying to get my shoes now
the suit, the whole nine yards.
I put these in the dry cleaners.
this way you know,
they're nice and cleaned and pressed.
like,
where they all get together.
Pat told me. -SAM: Yeah.
And what do you think about it?
SAM: You think we might get our asses beat?
seven, eight, nine, ten, eleven...
"Get too fresh"?
you know what?
some of them don't. They-- the...
there to do good, they love us.
like,
thinks we're a bunch of fucking assholes.
I gotta go.
(INDISTINCT CHATTER ON TV)
PATRICK:
-(SMOOCHES) -PATRICK:
(CHUCKLES)
♪ (OMINOUS MUSIC PLAYING) ♪
(BIRDS SCREECHING)
this is getting... (CHUCKLES)
There's no turning back now. There's 200 cops inside.
Oh.
(LINE RINGING)
(OVER PHONE)
so check this out, man. We're at the national FOP event.
with all the presidents. We're, like, here.
(JEFF LAUGHING)
SAM: Do you have any ideas
man? I'm gonna use that.
JEFF:
Yeah.
♪ (OMINOUS MUSIC CONCLUDES) ♪
♪ (PATRICK VOCALIZES LOUDLY) ♪
♪ (SINGS INDISTINCTLY) ♪
♪ ...I'll come up And get you from the grave ♪
♪ Souls in the afterlife Cannot be saved ♪
SAM: Was that your death metal voice?
That was me freestyling.
(KNOCK ON DOOR)
-PATRICK: Uh. Yes. -TOM HAYES: Hello.
Tom?
Tom. Tom. -PATRICK: Hey. Come on in, Tom.
-How you doing? -Hi. I'm well. How are you?
Tom. -Nice to meet you.
as you know, we're doing a little documentary
uh, we tried to chat with Mr. Lozano.
Mr. Lozano is at the center of a, um, fundraising scandal.
do you know anything about that?
I-- I don't personally have any information on that.
'Cause that was-- that was internal
-to Metro Lodge. -Okay.
HAYES: It was their program. It wasn't a state program.
Robert Lozano never raised any funds
on behalf of the state of Texas Fraternal Order of Police.
okay. Cool. All right, cool.
I-- I'm hearing rumors you guys
are gonna stop fundraising?
uh, telephone solicitation
on behalf of the Texas Fraternal Order Police.
and why was that? -It's a dirty business.
I didn't want to wait to where it got to be
-a major controversy. -Interesting.
'cause I'm trying to understand
why the FOP lodges aren't able
to get more favorable splits when it comes to fundraising?
I-- It's just the nature of the business.
I'm sure whoever was in charge
I would hope they negotiated the best they could.
I understand.
I guess the FOP is just getting ripped off.
now, on a national level,
have you or anybody spoken to the national president
about these issues that I'm discussing
-with you today? -I never have.
It never comes up in your meetings or anything?
at the national level, I don't believe
I've ever been a part or heard a conversation
pertaining to telephone solicitation.
I don't believe the national does it.
on the state level, you're doing no telemarketing.
uh, still doing telemarketing?
I have no idea.
And I'm hearing that there's incentives issued
to get that contract.
you know, like backdoor deals.
I've never heard of that.
You've never heard anything-- any incentives
or anything like that?
I had a little bit of contact with the people
nor did I ever solicit anything,
or hear of anybody else
doing anything along those lines.
given the nature of that business,
-it wouldn't surprise me. -PATRICK: It wouldn't surprise you.
So...
um, maybe going downstairs
and showing me around a little?
I don't know what I'm gonna show you
yeah, I can walk around and you can film.
you don't mind?
why don't we do that? We'll just walk around, look around.
uh, we'll run into some of your friends.
(CHUCKLES) You never know.
if they see me
they're gonna go the other way.
-PATRICK: Ah! (LAUGHS) -They're policemen.
PATRICK: That's funny.
♪ (UPBEAT TECHNO SONG PLAYING OVER SPEAKER) ♪
-(ELEVATOR DOORS OPEN) -(ELEVATOR BELL DINGS)
yeah, we're gonna Have a good time... ♪
What are you recording for?
PATRICK: We're doing a little documentary.
-(ELEVATOR BEEPS) -On what?
PATRICK: The FOP.
we're doing a little story on it.
(ELEVATOR BELL DINGS)
this is probably about as far as we should go.
No one-- no one up here
no. No problem.
cool.
you could see
the head twist, you know.
da, da."
And then they see us in matching jackets.
SAM: You guys were wearing matching jackets?
his jacket and mine are pretty close.
It was like we were twins.
shit, who's that?
(WHISPERING) I think it's hotel security.
don't answer that.
Are they gonna kick us out?
pretend we're not here.
ADAM: They're on to us.
bro.
they don't.
PATRICK: Who?
PRODUCER:
so all the cops canceled. -They both canceled?
They-- they know. They know. It got around.
well then there's no reason to be here.
why are we gonna risk the footage that we have?
(CREW MEMBERS SPEAKING INDISTINCTLY)
(INDISTINCT CHATTER)
SAM:
PATRICK: That's him in the blue suit.
SAM:
he's there.
Just go. We're going right up to him. I want him.
(INDISTINCT CHATTER)
excuse me, Mr. Yates, right?
right?
-No? -Nope.
PATRICK: Okay.
um...
sir.
sir.
man, I'm not a-- I'm not Mr. Yates.
I understand. Now, I'm talking to you.
doing a documentary.
-YOES: On what? -PATRICK: About fundraising.
He denied he was even him.
SAM:
And I was very polite. He was talking to someone.
I stood there. I waited.
It wasn't like I tried to bum-rush him.
"Hi, Mr. Yates."
I'm not Mr. Yates."
SAM:
I'm calling him Mr. Yates?
you are. (LAUGHS)
PATRICK: Oh! That's why he said he wasn't him.
okay?
I fucked it up.
I apologize. I fucked that up.
I pronounced his name wrong.
♪ (SOFT MUSIC PLAYING) ♪
JEFF:
SAM: I was pretty convinced
that we'd hit the end of the line
and it was time for everyone to go home.
But then I started thinking back to Reverend James
and all the cops who were on the other side
of this thing.
REVEREND JAMES TRANKLE: There was a story in Chicago.
"We're raising money
for the families of fallen officers."
And then didn't give a dime of it to any of them.
SAM: Maybe we'd been trying the wrong police
and we should be talking to a cop
who said he got fucked by the scam.
♪ (SOFT MUSIC FADES) ♪
MIKE BYRNE: It's very rare for an officer
to go against FOP.
the Fraternal Order Police gave me a medal.
The telemarketers got their share.
The company that owned the telemarketer
FOP got what was remaining.
uh, I didn't get anything.
I felt...
betrayed by my union
because the telemarketers didn't do this on their own.
hired them.
My main intention was to stop this
they would just keep on going.
♪ (PENSIVE MUSIC PLAYING) ♪
MIKE: It was a class action suit.
Four hundred disabled police officers.
We brought people who received phone calls
and they testified that they thought
that all of their money was gonna go to Chicago
or officers killed in the line of duty.
At no time did a telemarketer say
that the money would be put in a general fund
amusement park visits,
so forth.
PATRICK: What happened? What was the outcome?
the judge ruled that it was the telemarketers
um...
in other words, they blamed it
on the telemarketer themselves.
they blamed it on the telemarketers
-themselves. -Same thing with CDG.
"You did a wonderful job."
nobody knows you.
take care, Mike.
Mike. Thank you, Mike.
Mike is a fucking great guy.
man.
they did him dirty.
-SAM: Dirty. -PATRICK: Dirty.
SAM: I don't know what it was about Mike Byrne
but it lit a new fire under Pat.
We're standing up for the little guy.
yeah, yeah, yeah. -Look, let’s not let--
Let's not let what happened to Mike happen ever again.
♪ (PENSIVE MUSIC PLAYING) ♪
PATRICK: I was the guy that used to call for the money.
I'm the guy that feels really bad about it
and I just wanna make it right.
SAM: And the timing was perfect.
Ann Ravel had kept her word
and got us a sit-down interview with Senator Richard Blumenthal
to see if he'd take up our case.
He'd tried cleaning up the telemarketing industry
back in the '90s
and had always been one of CDG's top enemies.
If someone calls claiming to be the police
call the police.
bro. -Let's go to D.C.
what? I think it's 12 hours from here.
-Is it 12 hours? -SAM: Yeah.
well, then that's what we gotta do.
hey... -(SAM CHUCKLES)
-...it beats flying. (LAUGHS) -(SAM LAUGHS)
PATRICK: This is it.
We have arrived. We are at the halls of power.
back here,
I wanna be taking a picture with...
And make sure you get a picture of me with the senator.
I will.
PATRICK: And I want it printed out
-and I want to frame it. -SAM: Of course.
-♪ (PENSIVE MUSIC CONCLUDES) ♪ -(INDISTINCT CHATTER)
he could be here at any time?
-SAM: Yes. -PRODUCER: Are you ready?
-ADAM: Yeah. -PATRICK: I'm ready.
when he comes in, I'll take 'em off
-in a dramatic-type fashion. -(INDISTINCT CHATTER)
I think he is here. I see movement.
RICHARD BLUMENTHAL: Just put it in my pants.
-(INDISTINCT CONVERSATION) -BLUMENTHAL:
BLUMENTHAL:
I've never done--
Senator.
Senator.
-Nice to meet you. -Good to see you.
how are you?
my name is Patrick.
good to meet you.
sir. -Okay.
um,
there's a billion-dollar scam being perpetrated
right under everybody's noses.
And the business model is telemarketing.
You have legitimate police organizations
getting together with telemarketers and...
(HESITATES) ...they're defrauding
the most vulnerable in this country.
fixed income.
when the telemarketer is done
it goes to the nonprofit
and then them boys get their hands on it.
The boiler room operations
they have convicted murderers calling for the police.
And you know what they're doing now?
PACs,
so this way they can skirt around regulations.
you know, compelling story.
Michael Byrne.
He got shot. He was nearly killed.
They raised millions of dollars.
not one dime.
Him and 400 Chicago police officers
had to sue to get the money to go to the right place.
there was a poor guy--
let me just say, I don't know anything
I understand,
I enforced laws that protect contributors
to charitable causes.
And I believe the Federal Trade Commission
has to do a more aggressive
and activist job of pursuing these fraudsters.
I have been to every commission in Washington
but the laws are not there to act most of the time.
you give me the details of who you've contacted
FTC, Ann Ravel, uh, every--
I've been up and down Washington.
Vladeck-- -Well, we should get my staff
all the facts that...
and then maybe we can...
get in contact with the FTC.
we've already been in contact.
Every agency I go to says
congressional action needs to be taken.
Their hands are tied.
We-- we need a hearing on this.
we need a hearing. We need to--
We've had a hearing on some of the pandemic scams...
-All right. This isn't-- -...the false cures.
we'll have another hearing.
it needs be, and--
we need to sit down and find out what you have here.
ADAM:
-PATRICK: Yes. -ADAM:
-Okay. -Congressional action needs
to be taken. Um...
before I leave...
-we will propose it. -You promise?
I have done this kind of work for a long time.
-I'm very focused on it. -PATRICK: I understand.
We'll do whatever we think is appropriate.
so we can meet with your staff and present--
My staff is right here. They're gonna meet with you right now.
sir.
Senator.
sir.
grab your mic.
BLUMENTHAL: Oh. Sorry.
(INDISTINCT CHATTER)
-SAM: Can we get a photo? -ADAM:
BLUMENTHAL: I've gotta run.
sir. -ADAM: Thanks very much.
Adam?
-ADAM: Awesome. Amazing job. -Was it?
-Did I? It was good? All right. -ADAM: Yes. Yes.
SAM: So we'll do this same setup with his staff
if they come back again.
-ADAM: Yeah. -PATRICK: You may
wanna supply them with all the information and the facts.
like, have his staff go through it.
So I-- I don't think there'll be a problem.
I think there's a good chance he'll act. I really do.
CREW MEMBER:
SAM:
♪ (SOMBER MUSIC PLAYING) ♪
uh...
practically.
(OVERLAPPING CHATTER)
STAFFER:
But was someone gonna talk to us real quick?
he said his staff is gonna be made available
to us to go over some stuff.
STAFFER:
PATRICK: Understandable.
STAFFER:
thanks-- Cool. -STAFFER:
ADAM: Thank you so much. We'll break down right now.
guys. -ADAM: Thank you.
All right.
♪ (SOMBER MUSIC FADES) ♪
♪ (PENSIVE MUSIC PLAYING) ♪
(LIGHT GUITAR STRUMMING)
Pat, how's your investigation going?
you do know we talked to the senator, right? Uh,
Ann Ravel hooked us up with Senator Blumenthal.
He did kind of promise me that he would look into it.
we followed up,
we heard nothing. We got crickets.
I don't know, I mean, you've talked to the FEC,
you've talked to members of Congress.
it seems like you guys have done everything
that you are able to do to get people
to pay attention to this.
I think you guys should be proud.
I'm back here with my producer.
and maybe police telemarketing scams
can never be stopped.
But Pat and I swore we would expose this industry
and we fucking did it.
dude. -Yeah, dude. We did it, bro.
man? Just in life, in general?
I-- You know, Adam had asked me one time if...
if I would consider running for office.
I've been thinking about that since he asked me
that might not be for me.
♪ (PENSIVE MUSIC CONTINUES) ♪
I have gone to great lengths to make myself
a productive citizen.
you tired, dude?
you know the deal.
SAM: I was in a pretty dark place
-when we met at CDG. -PATRICK: I know that.
you gave me hope, bro.
dude.
You gave me purpose. (CHUCKLES)
buddy. -SAM: Here we are, buddy.
you-- you-- we family, man.
we've been through a lot together, man.
Got you a present. Um...
that's fucking great.
I'll have this forever.
dude.
yeah, dude. Oh, yeah.
you're a fucking legend, bro.
(PATRICK LAUGHS)
♪ (PENSIVE MUSIC CONCLUDES) ♪
♪ ("OH HAIL NO" BY EL-P PLAYING) ♪
♪ Ever notice when you talk I just cut myself? ♪
♪ On some ultimate fuck you Go fuck yourself ♪
♪ Like that was so heartfelt You really touched yourself ♪
♪ I loved the part Where you cried ♪
♪ I liked nothing else ♪
critical breach ♪
beat minimalisimo ♪
♪ Make you spin Like you sniffing ♪
♪ That god particle ♪
an odd article ♪
♪
♪ Dawn treader rising ♪
gliding ♪
♪ Shuffle through the tides Of slime smiling ♪
♪ Could be the high Or just mind control dying ♪
♪ Fuck it Throw me on the problem pile ♪
♪ I'm a grin from the garbage Stained parchment ♪
♪ Peeking out of my blinds In the apartment ♪
♪ Waiting for that "Hark hear That archangel calling?" ♪
♪ Pocket full of air Plus nothing to wear ♪
♪ I’ve been told I was put here to fail ♪
♪ Never ask me to hail ♪
♪ Never ask me to hail ♪
♪ Never ask me to hail ♪
hail, hail, hail, Hail, hail, hail ♪
♪ (SONG CONCLUDES) ♪
Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.